@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness;
-$Test::BDD::Cucumber::Harness::VERSION = '0.39';
+$Test::BDD::Cucumber::Harness::VERSION = '0.40';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness - Base class for creating harnesses
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 DESCRIPTION
 
@@ -82,6 +82,20 @@ locations of consolidated matches, for highlighting.
 sub step { my ( $self, $context ) = @_; }
 sub step_done { my ( $self, $context, $result ) = @_; }
 
+=head2 sub_step
+
+=head2 sub_step_done
+
+As per C<step> and C<step_done>, but for steps that have been called from other
+steps. None of the included harnesses respond to these methods, because
+generally the whole thing should be transparent, and the parent step handles
+passes, failures, etc.
+
+=cut
+
+sub sub_step { my ( $self, $context ) = @_; }
+sub sub_step_done { my ( $self, $context, $result ) = @_; }
+
 =head2 startup
 
 =head2 shutdown
