@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Loader;
-$Test::BDD::Cucumber::Loader::VERSION = '0.39';
+$Test::BDD::Cucumber::Loader::VERSION = '0.40';
 =head1 NAME
 
 Test::BDD::Cucumber::Loader - Simplify loading of Step Definition and feature files
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 DESCRIPTION
 
@@ -58,13 +58,13 @@ sub load {
     # Grab the feature files
     my @features = map {
         my $file = file($_);
-        my $feature
-            = Test::BDD::Cucumber::Parser->parse_file( $file, $tag_scheme );
-        } (
+        my $feature =
+          Test::BDD::Cucumber::Parser->parse_file( $file, $tag_scheme );
+      } (
         $file
         ? ( $file . '' )
         : File::Find::Rule->file()->name('*.feature')->in($dir)
-        );
+      );
 
     return ( $executor, @features );
 }
@@ -76,7 +76,7 @@ sub load_steps {
         $executor->add_steps( Test::BDD::Cucumber::StepFile->load($path) );
     } else {
         $executor->add_steps( Test::BDD::Cucumber::StepFile->load($_) )
-            for File::Find::Rule->file()->name('*_steps.pl')->in($path);
+          for File::Find::Rule->file()->name('*_steps.pl')->in($path);
     }
 
     return $class;
